@@ -36,7 +36,7 @@ class CliArguments:
 
 
 class RelyComplyCLI:
-    def __init__(self, **credentials):        
+    def __init__(self, **credentials):
         self._gql = None
         self.credentials = credentials
 
@@ -83,7 +83,7 @@ class RelyComplyCLI:
             ),
         )
         parser.add_argument("type", help="the type of object to perform an action on")
-        parser.add_argument("action", help="the action to perform")
+        parser.add_argument("action", help="the action to perform", default=None)
 
         parser.add_argument(
             "--debug",
@@ -126,10 +126,8 @@ class RelyComplyCLI:
 
         base_64_fields = uppercase_dict(self.gql.templates["Base64Fields"])
 
-        return field in base_64_fields.get(type.upper(), {}).get(
-            action.upper(), []
-        )
-        
+        return field in base_64_fields.get(type.upper(), {}).get(action.upper(), [])
+
     def parse_args(self, args):
         parser = self.get_argument_parser()
         set_args, other_args = parser.parse_known_args(args)
@@ -145,7 +143,7 @@ class RelyComplyCLI:
             )
 
         kwargs = {}
-        
+
         for key, value in raw_kwargs.items():
             if key.startswith("@"):
                 # This is a file reference we load the file and maybe base64 encode it
@@ -156,7 +154,7 @@ class RelyComplyCLI:
                 else:
                     with open(value, "r") as f:
                         new_value = f.read()
-                        
+
                 kwargs[new_key] = new_value
             else:
                 # We check if the value is json encoded, and decode it, otherwise it is just a string
